@@ -15,6 +15,8 @@
 
 static void detectQualcomm(FFCPUResult* cpu)
 {
+    // https://en.wikipedia.org/wiki/List_of_Qualcomm_Snapdragon_systems_on_chips
+
     if (ffStrbufEqualS(&cpu->name, "SM8635"))
         ffStrbufSetStatic(&cpu->name, "Qualcomm Snapdragon 8s Gen 3 [SM8635]");
     else if (ffStrbufEqualS(&cpu->name, "SM8650-AC"))
@@ -32,6 +34,8 @@ static void detectQualcomm(FFCPUResult* cpu)
 
     else if (ffStrbufEqualS(&cpu->name, "SM7675"))
         ffStrbufSetStatic(&cpu->name, "Qualcomm Snapdragon 7+ Gen 3 [SM7675]");
+    else if (ffStrbufEqualS(&cpu->name, "SM7635"))
+        ffStrbufSetStatic(&cpu->name, "Qualcomm Snapdragon 7s Gen 3 [SM7635]");
     else if (ffStrbufEqualS(&cpu->name, "SM7550"))
         ffStrbufSetStatic(&cpu->name, "Qualcomm Snapdragon 7 Gen 3 [SM7550]");
     else if (ffStrbufEqualS(&cpu->name, "SM7475"))
@@ -43,6 +47,10 @@ static void detectQualcomm(FFCPUResult* cpu)
 
     else if (ffStrbufEqualS(&cpu->name, "SM6375-AC"))
         ffStrbufSetStatic(&cpu->name, "Qualcomm Snapdragon 6s Gen 3 [SM6375-AC]");
+    else if (ffStrbufEqualS(&cpu->name, "SM6475"))
+        ffStrbufSetStatic(&cpu->name, "Qualcomm Snapdragon 6 Gen 3 [SM6475]");
+    else if (ffStrbufEqualS(&cpu->name, "SM6115"))
+        ffStrbufSetStatic(&cpu->name, "Qualcomm Snapdragon 6s Gen 1 [SM6115]");
     else if (ffStrbufEqualS(&cpu->name, "SM6450"))
         ffStrbufSetStatic(&cpu->name, "Qualcomm Snapdragon 6 Gen 1 [SM6450]");
 
@@ -74,7 +82,7 @@ static void detectAndroid(FFCPUResult* cpu)
 }
 #endif
 
-#ifdef __aarch64__
+#if __arm__ || __aarch64__
 #include "cpu_arm.h"
 
 static void detectArmName(FILE* cpuinfo, FFCPUResult* cpu, uint32_t implId)
@@ -82,44 +90,51 @@ static void detectArmName(FILE* cpuinfo, FFCPUResult* cpu, uint32_t implId)
     FF_AUTO_FREE char* line = NULL;
     rewind(cpuinfo);
     size_t len = 0;
-    const char* lastName = NULL;
+    uint32_t lastPartId = UINT32_MAX;
     uint32_t num = 0;
     while(getline(&line, &len, cpuinfo) != -1)
     {
         if (!ffStrStartsWith(line, "CPU part\t: ")) continue;
         uint32_t partId = (uint32_t) strtoul(line + strlen("CPU part\t: "), NULL, 16);
         const char* name = NULL;
-        switch (implId)
+        if (partId > 0) // Linux reports 0 for unknown CPUs
         {
-            case 0x41: name = armPartId2name(partId); break;
-            case 0x42: name = brcmPartId2name(partId); break;
-            case 0x43: name = caviumPartId2name(partId); break;
-            case 0x44: name = decPartId2name(partId); break;
-            case 0x46: name = fujitsuPartId2name(partId); break;
-            case 0x48: name = hisiPartId2name(partId); break;
-            case 0x4e: name = nvidiaPartId2name(partId); break;
-            case 0x50: name = apmPartId2name(partId); break;
-            case 0x51: name = qcomPartId2name(partId); break;
-            case 0x53: name = samsungPartId2name(partId); break;
-            case 0x56: name = marvellPartId2name(partId); break;
-            case 0x61: name = applePartId2name(partId); break;
-            case 0x66: name = faradayPartId2name(partId); break;
-            case 0x69: name = intelPartId2name(partId); break;
-            case 0x6d: name = msPartId2name(partId); break;
-            case 0x70: name = ftPartId2name(partId); break;
-            case 0xc0: name = amperePartId2name(partId); break;
-            default: name = "Unknown"; break;
+            switch (implId)
+            {
+                case 0x41: name = armPartId2name(partId); break;
+                case 0x42: name = brcmPartId2name(partId); break;
+                case 0x43: name = caviumPartId2name(partId); break;
+                case 0x44: name = decPartId2name(partId); break;
+                case 0x46: name = fujitsuPartId2name(partId); break;
+                case 0x48: name = hisiPartId2name(partId); break;
+                case 0x4e: name = nvidiaPartId2name(partId); break;
+                case 0x50: name = apmPartId2name(partId); break;
+                case 0x51: name = qcomPartId2name(partId); break;
+                case 0x53: name = samsungPartId2name(partId); break;
+                case 0x56: name = marvellPartId2name(partId); break;
+                case 0x61: name = applePartId2name(partId); break;
+                case 0x66: name = faradayPartId2name(partId); break;
+                case 0x69: name = intelPartId2name(partId); break;
+                case 0x6d: name = msPartId2name(partId); break;
+                case 0x70: name = ftPartId2name(partId); break;
+                case 0xc0: name = amperePartId2name(partId); break;
+            }
         }
-        if (lastName != name)
+        if (lastPartId != partId)
         {
-            if (lastName)
+            if (lastPartId != UINT32_MAX)
             {
                 if (num > 1)
                     ffStrbufAppendF(&cpu->name, "*%u", num);
                 ffStrbufAppendS(&cpu->name, " + ");
             }
-            ffStrbufAppendS(&cpu->name, name);
-            lastName = name;
+            if (name)
+                ffStrbufAppendS(&cpu->name, name);
+            else if (partId)
+                ffStrbufAppendF(&cpu->name, "%s-%X", cpu->vendor.chars, partId);
+            else
+                ffStrbufAppend(&cpu->name, &cpu->vendor);
+            lastPartId = partId;
             num = 1;
         }
         else
@@ -130,36 +145,52 @@ static void detectArmName(FILE* cpuinfo, FFCPUResult* cpu, uint32_t implId)
 }
 #endif
 
-static const char* parseCpuInfo(FILE* cpuinfo, FFCPUResult* cpu, FFstrbuf* physicalCoresBuffer, FFstrbuf* cpuMHz, FFstrbuf* cpuIsa, FFstrbuf* cpuUarch, FFstrbuf* cpuImplementer)
+static const char* parseCpuInfo(
+    FF_MAYBE_UNUSED FILE* cpuinfo,
+    FF_MAYBE_UNUSED FFCPUResult* cpu,
+    FF_MAYBE_UNUSED FFstrbuf* physicalCoresBuffer,
+    FF_MAYBE_UNUSED FFstrbuf* cpuMHz,
+    FF_MAYBE_UNUSED FFstrbuf* cpuIsa,
+    FF_MAYBE_UNUSED FFstrbuf* cpuUarch,
+    FF_MAYBE_UNUSED FFstrbuf* cpuImplementer)
 {
     FF_AUTO_FREE char* line = NULL;
     size_t len = 0;
 
     while(getline(&line, &len, cpuinfo) != -1)
     {
-        //Stop after the first CPU
-        if(*line == '\0' || *line == '\n')
+        //Stop after reasonable information is acquired
+        if((*line == '\0' || *line == '\n')
+            #if __arm__ || __loongarch__
+            && cpu->name.length > 0 // #1202 #1204
+            #endif
+        )
             break;
 
         (void)(
-            ffParsePropLine(line, "model name :", &cpu->name) ||
-            ffParsePropLine(line, "vendor_id :", &cpu->vendor) ||
-            ffParsePropLine(line, "cpu cores :", physicalCoresBuffer) ||
-            ffParsePropLine(line, "cpu MHz :", cpuMHz) ||
-            ffParsePropLine(line, "isa :", cpuIsa) ||
-            ffParsePropLine(line, "uarch :", cpuUarch) ||
-
-            #if __aarch64__
-            (cpu->vendor.length == 0 && ffParsePropLine(line, "CPU implementer :", cpuImplementer)) ||
+            // arm64 doesn't have "model name"; arm32 does have "model name" but its value is not useful.
+            // "Hardware" should always be used in this case
+            #if !(__arm__ || __aarch64__)
+            (cpu->name.length == 0 && ffParsePropLine(line, "model name :", &cpu->name)) ||
+            (cpu->vendor.length == 0 && ffParsePropLine(line, "vendor_id :", &cpu->vendor)) ||
+            (physicalCoresBuffer->length == 0 && ffParsePropLine(line, "cpu cores :", physicalCoresBuffer)) ||
+            (cpuMHz->length == 0 && ffParsePropLine(line, "cpu MHz :", cpuMHz)) ||
             #endif
-            #if __ANDROID__
+
+            #if !(__x86_64__ || __i386__ || __arm__ || __aarch64__)
+            (cpuIsa->length == 0 && ffParsePropLine(line, "isa :", cpuIsa)) ||
+            (cpuUarch->length == 0 && ffParsePropLine(line, "uarch :", cpuUarch)) ||
+            #endif
+
+            #if __arm__ || __aarch64__
+            (cpuImplementer->length == 0 && ffParsePropLine(line, "CPU implementer :", cpuImplementer)) ||
             (cpu->name.length == 0 && ffParsePropLine(line, "Hardware :", &cpu->name)) || //For Android devices
             #endif
             #if __powerpc__ || __powerpc
-            (cpu->name.length == 0 && ffParsePropLine(line, "cpu     :", &cpu->name)) || //For POWER
+            (cpu->name.length == 0 && ffParsePropLine(line, "cpu :", &cpu->name)) || //For POWER
             #endif
             #if __mips__
-            (cpu->name.length == 0 && ffParsePropLine(line, "cpu model               :", &cpu->name)) || //For MIPS
+            (cpu->name.length == 0 && ffParsePropLine(line, "cpu model :", &cpu->name)) || //For MIPS
             #endif
             false
         );
@@ -258,16 +289,19 @@ static double detectCPUTemp(void)
     {
         if(
             ffStrbufFirstIndexS(&value->name, "cpu") < value->name.length ||
-            ffStrbufCompS(&value->name, "k10temp") == 0 ||
-            ffStrbufCompS(&value->name, "coretemp") == 0
+            ffStrbufEqualS(&value->name, "k10temp") ||
+            ffStrbufEqualS(&value->name, "coretemp")
         ) return value->value;
     }
 
     return FF_CPU_TEMP_UNSET;
 }
 
-static void parseIsa(FFstrbuf* cpuIsa)
+FF_MAYBE_UNUSED static void parseIsa(FFstrbuf* cpuIsa)
 {
+    // Always use the last part of the ISA string. Ref: #590 #1204
+    ffStrbufSubstrAfterLastC(cpuIsa, ' ');
+
     if(ffStrbufStartsWithS(cpuIsa, "rv"))
     {
         // RISC-V ISA string example: "rv64imafdch_zicsr_zifencei".
@@ -283,31 +317,53 @@ static void parseIsa(FFstrbuf* cpuIsa)
         }
         // The final ISA output of the above example is "rv64gch".
     }
-    if(ffStrbufStartsWithS(cpuIsa, "mips"))
-    {
-        ffStrbufSubstrAfterLastC(cpuIsa, ' ');
-    }
 }
 
-void detectAsahi(FFCPUResult* cpu)
+FF_MAYBE_UNUSED static void detectArmSoc(FFCPUResult* cpu)
 {
-    // In Asahi Linux, reading /proc/device-tree/compatible gives
-    // information on the device model. It consists of 3 NUL terminated
-    // strings, the second of which gives the actual SoC model. But it
-    // is not the marketing name, i.e. for M2 there is "apple,t8112" in
-    // the compatible string.
-    if (cpu->name.length == 0 && ffStrbufEqualS(&cpu->vendor, "Apple"))
-    {
-        char content[32];
-        ssize_t length = ffReadFileData("/proc/device-tree/compatible", sizeof(content), content);
-        if (length <= 0) return;
+    if (cpu->name.length > 0)
+        return;
 
-        // get the second NUL terminated string
-        char* modelName = memchr(content, '\0', (size_t) length) + 1;
-        if (modelName - content < length && ffStrStartsWith(modelName, "apple,t"))
+    // device-vendor,device-model\0soc-vendor,soc-model\0
+    char content[64];
+    ssize_t length = ffReadFileData("/proc/device-tree/compatible", sizeof(content), content);
+    if (length <= 2) return;
+
+    // get the second NUL terminated string
+    char* modelName = memchr(content, '\0', (size_t) length) + 1;
+    if (!modelName || modelName - content >= length) return;
+
+    if (ffStrStartsWith(modelName, "apple,t"))
+    {
+        // https://elixir.bootlin.com/linux/v6.11-rc7/source/arch/arm64/boot/dts/apple
+        const char* code = modelName + strlen("apple,t");
+        uint32_t deviceId = (uint32_t) strtoul(code, NULL, 10);
+        ffStrbufSetStatic(&cpu->name, ffCPUAppleCodeToName(deviceId));
+        if (!cpu->name.length)
         {
-            uint32_t deviceId = (uint32_t) strtoul(modelName + strlen("apple,t"), NULL, 10);
-            ffStrbufSetStatic(&cpu->name, ffCPUAppleCodeToName(deviceId));
+            ffStrbufAppendS(&cpu->name, "Apple Silicon T");
+            ffStrbufAppendS(&cpu->name, code);
+        }
+    }
+    else if (ffStrStartsWith(modelName, "qcom,"))
+    {
+        // https://elixir.bootlin.com/linux/v6.11-rc7/source/arch/arm64/boot/dts/qcom
+        if (ffStrStartsWith(modelName + strlen("qcom,"), "x"))
+        {
+            ffStrbufSetS(&cpu->name, "Qualcomm Snapdragon X Elite ");
+            for (const char* p = modelName + strlen("qcom,"); *p; ++p)
+                ffStrbufAppendC(&cpu->name, (char) toupper(*p));
+        }
+        else if (ffStrStartsWith(modelName + strlen("qcom,"), "sc"))
+        {
+            const char* code = modelName + strlen("qcom,sc");
+            uint32_t deviceId = (uint32_t) strtoul(code, NULL, 10);
+            ffStrbufSetStatic(&cpu->name, ffCPUQualcommCodeToName(deviceId));
+            if (!cpu->name.length)
+            {
+                ffStrbufAppendS(&cpu->name, "Qualcomm Snapdragon SC");
+                ffStrbufAppendS(&cpu->name, code);
+            }
         }
     }
 }
@@ -333,9 +389,12 @@ const char* ffDetectCPUImpl(const FFCPUOptions* options, FFCPUResult* cpu)
     cpu->coresOnline = (uint16_t) get_nprocs();
     cpu->coresPhysical = (uint16_t) ffStrbufToUInt(&physicalCoresBuffer, cpu->coresLogical);
 
+    // Ref https://github.com/fastfetch-cli/fastfetch/issues/1194#issuecomment-2295058252
+    ffCPUDetectSpeedByCpuid(cpu);
     if (!detectFrequency(cpu, options) || cpu->frequencyBase == 0)
         cpu->frequencyBase = (uint32_t) ffStrbufToUInt(&cpuMHz, 0);
 
+    #if !(__x86_64__ || __i386__ || __arm__ || __aarch64__)
     if(cpuUarch.length > 0)
     {
         if(cpu->name.length > 0)
@@ -350,21 +409,18 @@ const char* ffDetectCPUImpl(const FFCPUOptions* options, FFCPUResult* cpu)
             ffStrbufAppendC(&cpu->name, ' ');
         ffStrbufAppend(&cpu->name, &cpuIsa);
     }
+    #endif
 
-    #ifdef __aarch64__
+    #if __arm__ || __aarch64__
     uint32_t cpuImplementer = (uint32_t) strtoul(cpuImplementerStr.chars, NULL, 16);
     ffStrbufSetStatic(&cpu->vendor, hwImplId2Vendor(cpuImplementer));
-    #endif
 
-    #ifdef __ANDROID__
+    #if __ANDROID__
     detectAndroid(cpu);
+    #elif __aarch64__
+    detectArmSoc(cpu);
     #endif
 
-    #if defined(__linux__) && defined(__aarch64__) && !defined(__ANDROID__)
-    detectAsahi(cpu);
-    #endif
-
-    #ifdef __aarch64__
     if (cpu->name.length == 0)
         detectArmName(cpuinfo, cpu, cpuImplementer);
     #endif
