@@ -58,8 +58,12 @@ typedef struct FFDisplayResult
     FFstrbuf name;
     FFDisplayType type;
     uint32_t rotation;
-    bool primary;
     uint64_t id; // platform dependent
+    uint32_t physicalWidth;
+    uint32_t physicalHeight;
+    bool primary;
+    uint8_t bitDepth;
+    bool hdrEnabled;
 } FFDisplayResult;
 
 typedef struct FFDisplayServerResult
@@ -74,7 +78,7 @@ typedef struct FFDisplayServerResult
 
 const FFDisplayServerResult* ffConnectDisplayServer();
 
-bool ffdsAppendDisplay(
+FFDisplayResult* ffdsAppendDisplay(
     FFDisplayServerResult* result,
     uint32_t width,
     uint32_t height,
@@ -85,4 +89,6 @@ bool ffdsAppendDisplay(
     FFstrbuf* name,
     FFDisplayType type,
     bool primary,
-    uint64_t id);
+    uint64_t id,
+    uint32_t physicalWidth,
+    uint32_t physicalHeight);
