@@ -14,26 +14,23 @@ static inline char* realpath(const char* restrict file_name, char* restrict reso
 }
 #endif
 
-static bool extractNvimVersionFromBinary(const char* str, uint32_t len, void* userdata)
+static bool extractNvimVersionFromBinary(const char* str, FF_MAYBE_UNUSED uint32_t len, void* userdata)
 {
-    if (len < strlen("NVIM v0.0.0")) return true;
     if (!ffStrStartsWith(str, "NVIM v")) return true;
     ffStrbufSetS((FFstrbuf*) userdata, str + strlen("NVIM v"));
     return false;
 }
 
-static bool extractVimVersionFromBinary(const char* str, uint32_t len, void* userdata)
+static bool extractVimVersionFromBinary(const char* str, FF_MAYBE_UNUSED uint32_t len, void* userdata)
 {
-    if (len < strlen("VIM - Vi IMproved 0.0")) return true;
     if (!ffStrStartsWith(str, "VIM - Vi IMproved ")) return true;
     ffStrbufSetS((FFstrbuf*) userdata, str + strlen("VIM - Vi IMproved "));
     ffStrbufSubstrBeforeFirstC(userdata, ' ');
     return false;
 }
 
-static bool extractNanoVersionFromBinary(const char* str, uint32_t len, void* userdata)
+static bool extractNanoVersionFromBinary(const char* str, FF_MAYBE_UNUSED uint32_t len, void* userdata)
 {
-    if (len < strlen("GNU nano 0.0")) return true;
     if (!ffStrStartsWith(str, "GNU nano ")) return true;
     ffStrbufSetS((FFstrbuf*) userdata, str + strlen("GNU nano "));
     return false;
@@ -97,11 +94,11 @@ const char* ffDetectEditor(FFEditorResult* result)
     if (!instance.config.general.detectVersion) return NULL;
 
     if (ffStrbufEqualS(&result->exe, "nvim"))
-        ffBinaryExtractStrings(result->path.chars, extractNvimVersionFromBinary, &result->version);
+        ffBinaryExtractStrings(result->path.chars, extractNvimVersionFromBinary, &result->version, (uint32_t) strlen("NVIM v0.0.0"));
     else if (ffStrbufEqualS(&result->exe, "vim"))
-        ffBinaryExtractStrings(result->path.chars, extractVimVersionFromBinary, &result->version);
+        ffBinaryExtractStrings(result->path.chars, extractVimVersionFromBinary, &result->version, (uint32_t) strlen("VIM - Vi IMproved 0.0"));
     else if (ffStrbufEqualS(&result->exe, "nano"))
-        ffBinaryExtractStrings(result->path.chars, extractNanoVersionFromBinary, &result->version);
+        ffBinaryExtractStrings(result->path.chars, extractNanoVersionFromBinary, &result->version, (uint32_t) strlen("GNU nano 0.0"));
 
     if (result->version.length > 0) return NULL;
 
