@@ -6,7 +6,7 @@
 
 #include <math.h>
 
-#define FF_DISPLAY_NUM_FORMAT_ARGS 16
+#define FF_DISPLAY_NUM_FORMAT_ARGS 15
 
 static int sortByNameAsc(FFDisplayResult* a, FFDisplayResult* b)
 {
@@ -91,10 +91,11 @@ void ffPrintDisplay(FFDisplayOptions* options)
         }
         else
         {
-            FF_PARSE_FORMAT_STRING_CHECKED(&key, &options->moduleArgs.key, 3, ((FFformatarg[]){
-                {FF_FORMAT_ARG_TYPE_UINT, &moduleIndex, "index"},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &result->name, "name"},
-                {FF_FORMAT_ARG_TYPE_STRING, displayType, "type"},
+            FF_PARSE_FORMAT_STRING_CHECKED(&key, &options->moduleArgs.key, 4, ((FFformatarg[]){
+                FF_FORMAT_ARG(moduleIndex, "index"),
+                FF_FORMAT_ARG(result->name, "name"),
+                FF_FORMAT_ARG(displayType, "type"),
+                FF_FORMAT_ARG(options->moduleArgs.keyIcon, "icon"),
             }));
         }
 
@@ -139,23 +140,33 @@ void ffPrintDisplay(FFDisplayOptions* options)
         {
             double ppi = sqrt(result->width * result->width + result->height * result->height) / inch;
 
+            char refreshRate[16];
+            if(result->refreshRate > 0)
+            {
+                if(options->preciseRefreshRate)
+                    snprintf(refreshRate, sizeof(refreshRate), "%g", ((int) (result->refreshRate * 1000 + 0.5)) / 1000.0);
+                else
+                    snprintf(refreshRate, sizeof(refreshRate), "%i", (uint32_t) (result->refreshRate + 0.5));
+            }
+            else
+                refreshRate[0] = 0;
+
             FF_PRINT_FORMAT_CHECKED(key.chars, 0, &options->moduleArgs, FF_PRINT_TYPE_NO_CUSTOM_KEY, FF_DISPLAY_NUM_FORMAT_ARGS, ((FFformatarg[]) {
-                {FF_FORMAT_ARG_TYPE_UINT, &result->width, "width"},
-                {FF_FORMAT_ARG_TYPE_UINT, &result->height, "height"},
-                {FF_FORMAT_ARG_TYPE_DOUBLE, &result->refreshRate, "refresh-rate"},
-                {FF_FORMAT_ARG_TYPE_UINT, &result->scaledWidth, "scaled-width"},
-                {FF_FORMAT_ARG_TYPE_UINT, &result->scaledHeight, "scaled-height"},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &result->name, "name"},
-                {FF_FORMAT_ARG_TYPE_STRING, displayType, "type"},
-                {FF_FORMAT_ARG_TYPE_UINT, &result->rotation, "rotation"},
-                {FF_FORMAT_ARG_TYPE_BOOL, &result->primary, "is-primary"},
-                {FF_FORMAT_ARG_TYPE_UINT, &result->physicalWidth, "physical-width"},
-                {FF_FORMAT_ARG_TYPE_UINT, &result->physicalHeight, "physical-height"},
-                {FF_FORMAT_ARG_TYPE_DOUBLE, &inch, "inch"},
-                {FF_FORMAT_ARG_TYPE_DOUBLE, &ppi, "ppi"},
-                {FF_FORMAT_ARG_TYPE_UINT8, &result->bitDepth, "bit-depth"},
-                {FF_FORMAT_ARG_TYPE_BOOL, &result->hdrEnabled, "hdr-enabled"},
-                {FF_FORMAT_ARG_TYPE_BOOL, &result->wcgEnabled, "wcg-enabled"},
+                FF_FORMAT_ARG(result->width, "width"),
+                FF_FORMAT_ARG(result->height, "height"),
+                FF_FORMAT_ARG(refreshRate, "refresh-rate"),
+                FF_FORMAT_ARG(result->scaledWidth, "scaled-width"),
+                FF_FORMAT_ARG(result->scaledHeight, "scaled-height"),
+                FF_FORMAT_ARG(result->name, "name"),
+                FF_FORMAT_ARG(displayType, "type"),
+                FF_FORMAT_ARG(result->rotation, "rotation"),
+                FF_FORMAT_ARG(result->primary, "is-primary"),
+                FF_FORMAT_ARG(result->physicalWidth, "physical-width"),
+                FF_FORMAT_ARG(result->physicalHeight, "physical-height"),
+                FF_FORMAT_ARG(inch, "inch"),
+                FF_FORMAT_ARG(ppi, "ppi"),
+                FF_FORMAT_ARG(result->bitDepth, "bit-depth"),
+                FF_FORMAT_ARG(result->hdrEnabled, "hdr-enabled"),
             }));
         }
     }
@@ -325,7 +336,6 @@ void ffGenerateDisplayJsonResult(FF_MAYBE_UNUSED FFDisplayOptions* options, yyjs
         yyjson_mut_obj_add_uint(doc, obj, "rotation", item->rotation);
         yyjson_mut_obj_add_uint(doc, obj, "bitDepth", item->bitDepth);
         yyjson_mut_obj_add_bool(doc, obj, "hdrEnabled", item->hdrEnabled);
-        yyjson_mut_obj_add_bool(doc, obj, "wcgEnabled", item->wcgEnabled);
 
         switch (item->type)
         {
@@ -360,7 +370,6 @@ void ffPrintDisplayHelpFormat(void)
         "Pixels per inch (PPI) - ppi",
         "Bits per color channel - bit-depth",
         "True if high dynamic range (HDR) is enabled - hdr-enabled",
-        "True if wide color gamut (WCG) is enabled - wcg-enabled",
     }));
 }
 
@@ -377,7 +386,7 @@ void ffInitDisplayOptions(FFDisplayOptions* options)
         ffPrintDisplayHelpFormat,
         ffGenerateDisplayJsonConfig
     );
-    ffOptionInitModuleArg(&options->moduleArgs);
+    ffOptionInitModuleArg(&options->moduleArgs, "󰍹");
     options->compactType = FF_DISPLAY_COMPACT_TYPE_NONE;
     options->preciseRefreshRate = false;
 }
