@@ -28,6 +28,10 @@ typedef enum FFPackagesFlags
     FF_PACKAGES_FLAG_XBPS_BIT = 1 << 18,
     FF_PACKAGES_FLAG_AM_BIT = 1 << 19,
     FF_PACKAGES_FLAG_SORCERY_BIT = 1 << 20,
+    FF_PACKAGES_FLAG_LPKG_BIT = 1 << 21,
+    FF_PACKAGES_FLAG_LPKGBUILD_BIT = 1 << 22,
+    FF_PACKAGES_FLAG_GUIX_BIT = 1 << 23,
+    FF_PACKAGES_FLAG_LINGLONG_BIT = 1 << 24,
 } FFPackagesFlags;
 
 typedef struct FFPackagesOptions
