@@ -82,43 +82,43 @@ void ffPrintPackages(FFPackagesOptions* options)
         uint32_t brewAll = counts.brew + counts.brewCask;
         uint32_t guixAll = counts.guixSystem + counts.guixUser + counts.guixHome;
         FF_PRINT_FORMAT_CHECKED(FF_PACKAGES_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_PACKAGES_NUM_FORMAT_ARGS, ((FFformatarg[]){
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.all, "all"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.pacman, "pacman"},
-            {FF_FORMAT_ARG_TYPE_STRBUF, &counts.pacmanBranch, "pacman-branch"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.dpkg, "dpkg"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.rpm, "rpm"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.emerge, "emerge"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.eopkg, "eopkg"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.xbps, "xbps"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.nixSystem, "nix-system"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.nixUser, "nix-user"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.nixDefault, "nix-default"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.apk, "apk"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.pkg, "pkg"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.flatpakSystem, "flatpak-system"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.flatpakUser, "flatpak-user"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.snap, "snap"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.brew, "brew"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.brewCask, "brew-cask"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.macports, "macports"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.scoop, "scoop"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.choco, "choco"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.pkgtool, "pkgtool"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.paludis, "paludis"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.winget, "winget"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.opkg, "opkg"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.am, "am"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.sorcery, "sorcery"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.lpkg, "lpkg"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.lpkgbuild, "lpkgbuild"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.guixSystem, "guix-system"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.guixUser, "guix-user"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.guixHome, "guix-home"},
-            {FF_FORMAT_ARG_TYPE_UINT, &counts.linglong, "linglong"},
-            {FF_FORMAT_ARG_TYPE_UINT, &nixAll, "nix-all"},
-            {FF_FORMAT_ARG_TYPE_UINT, &flatpakAll, "flatpak-all"},
-            {FF_FORMAT_ARG_TYPE_UINT, &brewAll, "brew-all"},
-            {FF_FORMAT_ARG_TYPE_UINT, &guixAll, "guix-all"},
+            FF_FORMAT_ARG(counts.all, "all"),
+            FF_FORMAT_ARG(counts.pacman, "pacman"),
+            FF_FORMAT_ARG(counts.pacmanBranch, "pacman-branch"),
+            FF_FORMAT_ARG(counts.dpkg, "dpkg"),
+            FF_FORMAT_ARG(counts.rpm, "rpm"),
+            FF_FORMAT_ARG(counts.emerge, "emerge"),
+            FF_FORMAT_ARG(counts.eopkg, "eopkg"),
+            FF_FORMAT_ARG(counts.xbps, "xbps"),
+            FF_FORMAT_ARG(counts.nixSystem, "nix-system"),
+            FF_FORMAT_ARG(counts.nixUser, "nix-user"),
+            FF_FORMAT_ARG(counts.nixDefault, "nix-default"),
+            FF_FORMAT_ARG(counts.apk, "apk"),
+            FF_FORMAT_ARG(counts.pkg, "pkg"),
+            FF_FORMAT_ARG(counts.flatpakSystem, "flatpak-system"),
+            FF_FORMAT_ARG(counts.flatpakUser, "flatpak-user"),
+            FF_FORMAT_ARG(counts.snap, "snap"),
+            FF_FORMAT_ARG(counts.brew, "brew"),
+            FF_FORMAT_ARG(counts.brewCask, "brew-cask"),
+            FF_FORMAT_ARG(counts.macports, "macports"),
+            FF_FORMAT_ARG(counts.scoop, "scoop"),
+            FF_FORMAT_ARG(counts.choco, "choco"),
+            FF_FORMAT_ARG(counts.pkgtool, "pkgtool"),
+            FF_FORMAT_ARG(counts.paludis, "paludis"),
+            FF_FORMAT_ARG(counts.winget, "winget"),
+            FF_FORMAT_ARG(counts.opkg, "opkg"),
+            FF_FORMAT_ARG(counts.am, "am"),
+            FF_FORMAT_ARG(counts.sorcery, "sorcery"),
+            FF_FORMAT_ARG(counts.lpkg, "lpkg"),
+            FF_FORMAT_ARG(counts.lpkgbuild, "lpkgbuild"),
+            FF_FORMAT_ARG(counts.guixSystem, "guix-system"),
+            FF_FORMAT_ARG(counts.guixUser, "guix-user"),
+            FF_FORMAT_ARG(counts.guixHome, "guix-home"),
+            FF_FORMAT_ARG(counts.linglong, "linglong"),
+            FF_FORMAT_ARG(nixAll, "nix-all"),
+            FF_FORMAT_ARG(flatpakAll, "flatpak-all"),
+            FF_FORMAT_ARG(brewAll, "brew-all"),
+            FF_FORMAT_ARG(guixAll, "guix-all"),
         }));
     }
 
