@@ -39,12 +39,12 @@ void ffPrintPowerAdapter(FFPowerAdapterOptions* options)
             else
             {
                 FF_PRINT_FORMAT_CHECKED(FF_POWERADAPTER_DISPLAY_NAME, i, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_POWERADAPTER_NUM_FORMAT_ARGS, ((FFformatarg[]){
-                    {FF_FORMAT_ARG_TYPE_INT, &result->watts, "watts"},
-                    {FF_FORMAT_ARG_TYPE_STRBUF, &result->name, "name"},
-                    {FF_FORMAT_ARG_TYPE_STRBUF, &result->manufacturer, "manufacturer"},
-                    {FF_FORMAT_ARG_TYPE_STRBUF, &result->modelName, "model-name"},
-                    {FF_FORMAT_ARG_TYPE_STRBUF, &result->description, "description"},
-                    {FF_FORMAT_ARG_TYPE_STRBUF, &result->serial, "serial"},
+                    FF_FORMAT_ARG(result->watts, "watts"),
+                    FF_FORMAT_ARG(result->name, "name"),
+                    FF_FORMAT_ARG(result->manufacturer, "manufacturer"),
+                    FF_FORMAT_ARG(result->modelName, "model-name"),
+                    FF_FORMAT_ARG(result->description, "description"),
+                    FF_FORMAT_ARG(result->serial, "serial"),
                 }));
             }
 
