@@ -26,7 +26,7 @@ void ffPrintProcesses(FFProcessesOptions* options)
     else
     {
         FF_PRINT_FORMAT_CHECKED(FF_PROCESSES_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_PROCESSES_NUM_FORMAT_ARGS, ((FFformatarg[]){
-            {FF_FORMAT_ARG_TYPE_UINT, &numProcesses, "result"}
+            FF_FORMAT_ARG(numProcesses, "result")
         }));
     }
 }
