@@ -13,7 +13,7 @@ void ffPrintTerminalTheme(FFTerminalThemeOptions* options)
 {
     FFTerminalThemeResult result = {};
 
-    if(!ffDetectTerminalTheme(&result))
+    if(!ffDetectTerminalTheme(&result, false))
     {
         ffPrintError(FF_TERMINALTHEME_DISPLAY_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Failed to detect terminal theme");
     }
@@ -30,13 +30,15 @@ void ffPrintTerminalTheme(FFTerminalThemeOptions* options)
         else
         {
             char fg[32], bg[32];
+            const char* fgType = result.fg.dark ? "Dark" : "Light";
+            const char* bgType = result.bg.dark ? "Dark" : "Light";
             snprintf(fg, sizeof(fg), "#%02" PRIX16 "%02" PRIX16 "%02" PRIX16, result.fg.r, result.fg.g, result.fg.b);
             snprintf(bg, sizeof(bg), "#%02" PRIX16 "%02" PRIX16 "%02" PRIX16, result.bg.r, result.bg.g, result.bg.b);
             FF_PRINT_FORMAT_CHECKED(FF_TERMINALTHEME_DISPLAY_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_TERMINALTHEME_NUM_FORMAT_ARGS, ((FFformatarg[]){
-                {FF_FORMAT_ARG_TYPE_STRING, fg},
-                {FF_FORMAT_ARG_TYPE_STRING, result.fg.dark ? "Dark" : "Light"},
-                {FF_FORMAT_ARG_TYPE_STRING, bg},
-                {FF_FORMAT_ARG_TYPE_STRING, result.bg.dark ? "Dark" : "Light"},
+                FF_FORMAT_ARG(fg, "fg-color"),
+                FF_FORMAT_ARG(fgType, "fg-type"),
+                FF_FORMAT_ARG(bg, "bg-color"),
+                FF_FORMAT_ARG(bgType, "bg-type"),
             }));
         }
     }
@@ -81,7 +83,7 @@ void ffGenerateTerminalThemeJsonResult(FF_MAYBE_UNUSED FFTerminalOptions* option
 {
     FFTerminalThemeResult result = {};
 
-    if(!ffDetectTerminalTheme(&result))
+    if(!ffDetectTerminalTheme(&result, false))
     {
         yyjson_mut_obj_add_str(doc, module, "error", "Failed to detect terminal theme");
         return;
@@ -105,10 +107,10 @@ void ffGenerateTerminalThemeJsonResult(FF_MAYBE_UNUSED FFTerminalOptions* option
 void ffPrintTerminalThemeHelpFormat(void)
 {
     FF_PRINT_MODULE_FORMAT_HELP_CHECKED(FF_TERMINALTHEME_MODULE_NAME, "{1} (FG) {3} (BG) [{4}]", FF_TERMINALTHEME_NUM_FORMAT_ARGS, ((const char* []) {
-        "Terminal foreground color",
-        "Terminal foreground type (Dark / Light)",
-        "Terminal background color",
-        "Terminal background type (Dark / Light)",
+        "Terminal foreground color - fg-color",
+        "Terminal foreground type (Dark / Light) - fg-type",
+        "Terminal background color - bg-color",
+        "Terminal background type (Dark / Light) - bg-type",
     }));
 }
 
@@ -125,7 +127,7 @@ void ffInitTerminalThemeOptions(FFTerminalThemeOptions* options)
         ffPrintTerminalThemeHelpFormat,
         ffGenerateTerminalThemeJsonConfig
     );
-    ffOptionInitModuleArg(&options->moduleArgs);
+    ffOptionInitModuleArg(&options->moduleArgs, "󰔎");
 }
 
 void ffDestroyTerminalThemeOptions(FFTerminalThemeOptions* options)
